# aind-metadata-service-async-client

## aind-metadata-service

Service to pull data from example backend.



This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.1.1
- Package version: 2.1.1
- Generator version: 7.13.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import aind_metadata_service_async_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import aind_metadata_service_async_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import aind_metadata_service_async_client
from aind_metadata_service_async_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = aind_metadata_service_async_client.Configuration(
    host = "http://localhost"
)



# Enter a context with an instance of the API client
async with aind_metadata_service_async_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = aind_metadata_service_async_client.DefaultApi(api_client)
    subject_id = '823508' # str | 

    try:
        # Get Procedures
        api_response = await api_instance.get_procedures(subject_id)
        print("The response of DefaultApi->get_procedures:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->get_procedures: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**get_procedures**](docs/DefaultApi.md#get_procedures) | **GET** /api/v2/procedures/{subject_id} | Get Procedures
*DefaultApi* | [**get_subject**](docs/DefaultApi.md#get_subject) | **GET** /api/v2/subject/{subject_id} | Get Subject
*DefaultApi* | [**get_v1_bergamo_session**](docs/DefaultApi.md#get_v1_bergamo_session) | **POST** /bergamo_session | Get V1 Bergamo Session
*DefaultApi* | [**get_v1_funding**](docs/DefaultApi.md#get_v1_funding) | **GET** /funding/{project_name} | Get V1 Funding
*DefaultApi* | [**get_v1_injection_materials**](docs/DefaultApi.md#get_v1_injection_materials) | **GET** /tars_injection_materials/{prep_lot_number} | Get V1 Injection Materials
*DefaultApi* | [**get_v1_instrument**](docs/DefaultApi.md#get_v1_instrument) | **GET** /instrument/{instrument_id} | Get V1 Instrument
*DefaultApi* | [**get_v1_intended_measurements**](docs/DefaultApi.md#get_v1_intended_measurements) | **GET** /intended_measurements/{subject_id} | Get V1 Intended Measurements
*DefaultApi* | [**get_v1_mgi_allele**](docs/DefaultApi.md#get_v1_mgi_allele) | **GET** /mgi_allele/{allele_name} | Get V1 Mgi Allele
*DefaultApi* | [**get_v1_perfusions**](docs/DefaultApi.md#get_v1_perfusions) | **GET** /perfusions/{subject_id} | Get V1 Perfusions
*DefaultApi* | [**get_v1_procedures**](docs/DefaultApi.md#get_v1_procedures) | **GET** /procedures/{subject_id} | Get V1 Procedures
*DefaultApi* | [**get_v1_project_names**](docs/DefaultApi.md#get_v1_project_names) | **GET** /project_names | Get V1 Project Names
*DefaultApi* | [**get_v1_protocols**](docs/DefaultApi.md#get_v1_protocols) | **GET** /protocols/{protocol_name} | Get V1 Protocols
*DefaultApi* | [**get_v1_rig**](docs/DefaultApi.md#get_v1_rig) | **GET** /rig/{rig_id} | Get V1 Rig
*DefaultApi* | [**get_v1_slims_workflow**](docs/DefaultApi.md#get_v1_slims_workflow) | **GET** /slims/{workflow} | Get V1 Slims Workflow
*DefaultApi* | [**get_v1_subject**](docs/DefaultApi.md#get_v1_subject) | **GET** /subject/{subject_id} | Get V1 Subject
*DefaultApi* | [**index**](docs/DefaultApi.md#index) | **GET** / | Index
*HealthcheckApi* | [**get_health**](docs/HealthcheckApi.md#get_health) | **GET** /api/v2/healthcheck | Perform a Health Check


## Documentation For Models

 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [HealthCheck](docs/HealthCheck.md)
 - [SlimsWorkflow](docs/SlimsWorkflow.md)
 - [ValidationError](docs/ValidationError.md)
 - [ValidationErrorLocInner](docs/ValidationErrorLocInner.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




